import 'package:flutter/material.dart';
import 'package:httpp/httpp.dart';

import 'src/microsoft_provider_service.dart';
import 'src/model/email/microsoft_provider_model_email.dart';
import 'src/model/microsoft_provider_model.dart';

export 'src/model/microsoft_provider_model.dart';

class MicrosoftProvider {
  late final MicrosoftProviderService _service;

  MicrosoftProvider(
      {Function(MicrosoftProviderModel)? onLink,
      Function(String?)? onUnlink,
      Function(
              {String? accessToken,
              DateTime? accessExp,
              String? refreshToken,
              DateTime? refreshExp})?
          onRefresh,
      Httpp? httpp})
      : _service = MicrosoftProviderService(
            httpp: httpp,
            onLink: onLink,
            onUnlink: onUnlink,
            onRefresh: onRefresh);

  MicrosoftProvider.loggedIn(
      {required String? token,
      String? email,
      String? displayName,
      String? refreshToken,
      Function(MicrosoftProviderModel)? onLink,
      Function(String?)? onUnlink,
      Function(
              {String? accessToken,
              DateTime? accessExp,
              String? refreshToken,
              DateTime? refreshExp})?
          onRefresh,
      Httpp? httpp}) {
    _service = MicrosoftProviderService(
        model: MicrosoftProviderModel(
          isLinked: true,
          email: email,
          token: token,
          displayName: displayName,
          refreshToken: refreshToken,
        ),
        httpp: httpp,
        onLink: onLink,
        onUnlink: onUnlink,
        onRefresh: onRefresh);
  }

  Widget accountWidget() => _service.presenter.accountButton();

  Future<void> fetchInbox(
          {DateTime? since,
          required Function(List<String> messagesIds) onResult,
          required Function() onFinish}) =>
      _service.email
          .fetchInbox(since: since, onResult: onResult, onFinish: onFinish);

  Future<void> fetchMessages(
          {required List<String> messageIds,
          required Function(MicrosoftProviderModelEmail message) onResult,
          required Function() onFinish}) =>
      _service.email.fetchMessages(
          messageIds: messageIds, onResult: onResult, onFinish: onFinish);

  Future<void> sendEmail(
          {String? body,
          required String to,
          String? subject,
          Function(bool)? onResult}) =>
      _service.email
          .send(body: body, to: to, subject: subject, onResult: onResult);

  Future<void> update({Function(MicrosoftProviderModel)? onUpdate}) async =>
      await _service.updateUserInfo();

  String? get displayName => _service.model.displayName;
}
